==> vsn-document-service-v0.0.25.zip: vsn-document-service-v0.0.25/CHANGELOG.md <==
## [0.0.25]
- 
## [0.0.24]
- 
## [0.0.23]
- 
## [0.0.22]
- 
## [0.0.21]
- 
## [0.0.20]
- 
## [0.0.19]
- 
## [0.0.18]
- 
## [0.0.17]
- 
## [0.0.16]
- 
## [0.0.15]
- 
## [0.0.14]
- 
## [0.0.13]
- 
## [0.0.12]
- 
## [0.0.11]
- 
## [0.0.10]
- Add folder favorite implementation
- Fix favorite bug in folderMapper
- Add bulk operations : delete, share, move on folders
- Create document/Upload new Document/s3 docs upload: implementations
- Add root documents to storage quota counting
- Document listing implementations
- Add documents statistics implementation
- Fix mappers issues and implement doc download features
- Document Sorting and Document Searching features implementations
- Folder search bug fix
- Delete Document methods implementations
- Folder Download bug fix
- Share Document With user / share On S3
- Share Many Documents at once With user / share On S3
- Favorite documents feature implementations
- Move documents implementations
## [0.0.9]
- 
## [0.0.8]
- 
## [0.0.7]
- 
## [0.0.6]
- 
## [0.0.5]
- 
## [0.0.4]
- 
## [0.0.4]
 - Storage Quota Service Implementation 
## [0.0.3]
- Implement folder sharing with other users
- Cancel folder sharing
- Zip/Compress folder implementation
- Implement Folder or Document Download feature
- implement folder storage quota feature
## [1.0.0]
- Create vsn-document-service
- Add Aws S3 config to the microservice
- externalize bucket region
- Add necessary dtos files
- Add folder creation implementation
- Rename Folder Method
- delete folder implementation
- Add controllers to previous implementations
- Move folder implementation
- List folders implementations
- BUG FIX
- Add folders search implementation
- Folder Details Implementation + Advanced search implementation

==> vsn-document-service-v0.0.28.zip: vsn-document-service-v0.0.28/CHANGELOG.md <==
## [0.0.28]
- 
## [0.0.28]
- 
## [0.0.27]
- 
## [0.0.26]
- Add cors configuration
- Allow null values for parent id
- Rename Document Implementation
- Document Service Refactoring: Folders Part
## [0.0.25]
- 
## [0.0.24]
- 
## [0.0.23]
- 
## [0.0.22]
- 
## [0.0.21]
- 
## [0.0.20]
- 
## [0.0.19]
- 
## [0.0.18]
- 
## [0.0.17]
- 
## [0.0.16]
- 
## [0.0.15]
- 
## [0.0.14]
- 
## [0.0.13]
- 
## [0.0.12]
- 
## [0.0.11]
- 
## [0.0.10]
- Add folder favorite implementation
- Fix favorite bug in folderMapper
- Add bulk operations : delete, share, move on folders
- Create document/Upload new Document/s3 docs upload: implementations
- Add root documents to storage quota counting
- Document listing implementations
- Add documents statistics implementation
- Fix mappers issues and implement doc download features
- Document Sorting and Document Searching features implementations
- Folder search bug fix
- Delete Document methods implementations
- Folder Download bug fix
- Share Document With user / share On S3
- Share Many Documents at once With user / share On S3
- Favorite documents feature implementations
- Move documents implementations
## [0.0.9]
- 
## [0.0.8]
- 
## [0.0.7]
- 
## [0.0.6]
- 
## [0.0.5]
- 
## [0.0.4]
- 
## [0.0.4]
 - Storage Quota Service Implementation 
## [0.0.3]
- Implement folder sharing with other users
- Cancel folder sharing
- Zip/Compress folder implementation
- Implement Folder or Document Download feature
- implement folder storage quota feature
## [1.0.0]
- Create vsn-document-service
- Add Aws S3 config to the microservice
- externalize bucket region
- Add necessary dtos files
- Add folder creation implementation
- Rename Folder Method
- delete folder implementation
- Add controllers to previous implementations
- Move folder implementation
- List folders implementations
- BUG FIX
- Add folders search implementation
- Folder Details Implementation + Advanced search implementation
